@@ -141,7 +141,7 @@ class HotStarIE(HotStarBaseIE):
 
         title = video_data['title']
 
-        if not self._downloader.params.get('allow_unplayable_formats') and video_data.get('drmProtected'):
+        if not self.get_param('allow_unplayable_formats') and video_data.get('drmProtected'):
             raise ExtractorError('This video is DRM protected.', expected=True)
 
         headers = {'Referer': url}
